@@ -5,7 +5,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 use DBI 1.40;
 use parent 'DBI';
@@ -721,10 +721,10 @@ DBIx::Query - Simplified abstracted chained DBI subclass
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
-=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/DBIx-Query.svg)](https://travis-ci.org/gryphonshafer/DBIx-Query)
-[![Coverage Status](https://coveralls.io/repos/gryphonshafer/DBIx-Query/badge.png)](https://coveralls.io/r/gryphonshafer/DBIx-Query)
+=for markdown [![test](https://github.com/gryphonshafer/DBIx-Query/workflows/test/badge.svg)](https://github.com/gryphonshafer/DBIx-Query/actions?query=workflow%3Atest)
+[![codecov](https://codecov.io/gh/gryphonshafer/DBIx-Query/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/DBIx-Query)
 
 =for test_synopsis my( $db_name, $db_host, $user, $pwd );
 
@@ -1357,11 +1357,11 @@ L<MetaCPAN|https://metacpan.org/pod/DBIx::Query>
 
 =item *
 
-L<Travis CI|https://travis-ci.org/gryphonshafer/DBIx-Query>
+L<GitHub Actions|https://github.com/gryphonshafer/DBIx-Query/actions>
 
 =item *
 
-L<Coveralls|https://coveralls.io/r/gryphonshafer/DBIx-Query>
+L<Codecov|https://codecov.io/gh/gryphonshafer/DBIx-Query>
 
 =item *
 
@@ -1379,9 +1379,10 @@ Gryphon Shafer <gryphon@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gryphon Shafer.
+This software is Copyright (c) 2013-2021 by Gryphon Shafer.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
